==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Vytvoriť rovinu obrázka...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>vytvoriť planárny obraz v 3D priestore</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>vytvoriť planárny obrázok v 3D priestore</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otvoriť...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otvoriť prehliadanie obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedefinovaný typ farebného systému pre prehliadanie obrázku</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixel formát obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Rovina XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ rovina</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ rovine</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odstup:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Celý obraz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Roztiahnút obrázok do pohľadu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;Mierka 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Zobratiť obrázok v mierke 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Originálne farby</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Zobraziť obrázok v jeho originálnych farbách</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Jasnejšie farby</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Zobraziť obrázok v jasnejších farbách</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Štandardné</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Hotovo...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>šedá</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Lupa</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>mimo obraz</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Prehliadač obrázkov</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Obrázky (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Vyberte súbor s obrázkom na otvorenie</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Obrázky</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Všetky súbory</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation type="unfinished">Error opening image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation type="unfinished">Could not load the chosen image</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Chyba otvoriť obrázok</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nepodarilo sa načítať obrázok</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sk" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Vytvoriť rovinu obrázka...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>vytvoriť planárny obraz v 3D priestore</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>vytvoriť planárny obrázok v 3D priestore</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Otvoriť...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Otvoriť prehliadanie obrázku</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation type="unfinished">Scale...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation type="unfinished">Image Scaling</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>Nedefinovaný typ farebného systému pre prehliadanie obrázku</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Pixel formát obrázku</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation type="unfinished">Image plane</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>Rovina XY</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ rovina</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ rovine</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Odstup:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>&amp;Celý obraz</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Roztiahnút obrázok do pohľadu</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;Mierka 1:1</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>Zobratiť obrázok v mierke 1:1</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Originálne farby</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Zobraziť obrázok v jeho originálnych farbách</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Jasnejšie farby</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Zobraziť obrázok v jasnejších farbách</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Štandardné</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Hotovo...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>šedá</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>Lupa</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>mimo obraz</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Prehliadač obrázkov</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Obrázky (*. png *. XPM *. jpg *. bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Vyberte súbor s obrázkom na otvorenie</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Obrázky</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Všetky súbory</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation type="unfinished">Error opening image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation type="unfinished">Could not load the chosen image</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Chyba otvoriť obrázok</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nepodarilo sa načítať obrázok</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Obrázok</translation>
    </message>
  </context>
</TS>
